@@ -1,5 +1,5 @@
 # bind global variables
-if(getRversion() >= "2.15.1") utils::globalVariables(c("fit"))
+if (getRversion() >= "2.15.1") utils::globalVariables(c("fit"))
 
 
 #' @title Compute eta-squared of fitted anova
@@ -58,7 +58,7 @@ eta_sq <- function(...) {
     fit <- aov(depVar ~ grpVar)
   }
   # return eta squared
-  return (summary.lm(fit)$r.squared)
+  return(summary.lm(fit)$r.squared)
   # return (1 - var(fit$residuals, na.rm = T) / var(fit$model[,1], na.rm = T))
 }
 
@@ -67,7 +67,7 @@ eta_sq <- function(...) {
 #' @name std_beta
 #' @description Returns the standardized beta coefficients and confidence intervals
 #'                of a fitted linear (mixed) models, i.e. \code{fit} must either
-#'                be of class \code{lm} or \code{lmerMod} (lme4-package).
+#'                be of class \code{lm} or \code{\link[lme4]{merMod}}.
 #'
 #' @param fit A fitted linear (mixed) model of class \code{\link{lm}} or \code{\link[lme4]{merMod}} (lme4-package).
 #' @param include.ci logical, if \code{TRUE}, a data frame with confidence intervals will be returned,
@@ -99,8 +99,8 @@ eta_sq <- function(...) {
 std_beta <- function(fit, include.ci = FALSE) {
   # if we have merMod object (lme4), we need
   # other function to compute std. beta
-  if (class(fit) == "lmerMod") {
-    return (sjs.stdmm(fit))
+  if (any(class(fit) == "lmerMod") || any(class(fit) == "merModLmerTest")) {
+    return(sjs.stdmm(fit))
   } else {
     b <- summary(fit)$coef[-1, 1]
     sx <- sapply(as.data.frame(fit$model)[-1], sd, na.rm = T)
@@ -111,9 +111,9 @@ std_beta <- function(fit, include.ci = FALSE) {
     # check if confidence intervals should also be returned
     # if yes, create data frame with sb and ci
     if (include.ci) {
-      return (data.frame(beta = beta,
-                         ci.low = (beta - beta.se * 1.96),
-                         ci.hi = (beta + beta.se * 1.96)))
+      return(data.frame(beta = beta,
+                        ci.low = (beta - beta.se * 1.96),
+                        ci.hi = (beta + beta.se * 1.96)))
     } else {
       return(beta)
     }
@@ -144,7 +144,7 @@ sjs.stdmm <- function(fit) {
 #' @title Performs a Mann-Whitney-U-Test
 #' @name mwu
 #' @description This function performs a Mann-Whitney-U-Test (or \code{Wilcoxon rank sum test},
-#'                see \code{\link{wilcox.test}} and \code{\link[coin]{wilcox_test}}
+#'                see \code{\link{wilcox.test}} and \code{\link[coin]{wilcox_test}})
 #'                for the variable \code{var}, which is
 #'                divided into groups indicated by \code{grp} (so the formula \code{var ~ grp}
 #'                is used). If \code{grp} has more than two categories, a comparison between each
@@ -166,7 +166,7 @@ sjs.stdmm <- function(fit) {
 #' @note This function calls the \code{\link[coin]{wilcox_test}} with formula. If \code{grp}
 #'         has more than two groups, additionally a Kruskal-Wallis-Test (see \code{\link{kruskal.test}})
 #'         is performed. \cr \cr
-#'         Interpretation of effect sizes:
+#'         Interpretation of effect sizes, as a rule-of-thumb:
 #'         \itemize{
 #'          \item small effect >= 0.1
 #'          \item medium effect >= 0.3
@@ -308,21 +308,42 @@ mwu <- function(var, grp, distribution="asymptotic", weights=NULL) {
   # replace 0.001 with <0.001
   levels(tab.df$p)[which(levels(tab.df$p) == "0.001")] <- "<0.001"
   # return both data frames
-  invisible (structure(class = "mwu",list(df = df, tab.df = tab.df)))
+  invisible(structure(class = "mwu",list(df = df, tab.df = tab.df)))
 }
 
 
 #' @title Performs a Chi-square goodness-of-fit-test
 #' @name chisq_gof
 #'
-#' @param var a numeric vector / variable.
-#' @param prob a vector of probabilities (indicating the population probabilities) of the same length
-#'          as \code{var}'s amount of categories / factor levels. Use \code{nrow(table(var))} to
-#'          determine the amount of necessary values for \code{prob}.
-#' @param weights a vector with weights, used to weight \code{var}.
-#' @return (insisibly) returns the object of the computed \code{\link{chisq.test}}.
+#' @description This method performs a Chi-square goodness-of-fit-test (GOF)
+#'                either on a numeric vector against probabilities, or
+#'                a Goodness-of-fit tests for \code{\link{glm}}s for binary data.
 #'
-#' @note This function is a convenient function for \code{\link{chisq.test}}, performing goodness-of-fit test.
+#' @param x a numeric vector / variable, or a \code{\link{glm}}-object.
+#' @param prob a vector of probabilities (indicating the population probabilities) of the same length
+#'          as \code{x}'s amount of categories / factor levels. Use \code{nrow(table(x))} to
+#'          determine the amount of necessary values for \code{prob}. Only used,
+#'          when \code{x} is a vector, and not a \code{glm}-object.
+#' @param weights a vector with weights, used to weight \code{x}.
+#' @return For vectors, (insisibly) returns the object of the computed \code{\link{chisq.test}}.
+#'           \cr \cr
+#'           For \code{glm}-objects, an object of class \code{chisq_gof} with
+#'           following values:
+#'           \itemize{
+#'            \item \code{p.value}	the p-value for the goodness-of-fit test
+#'            \item \code{z.score} the standardized z-score for the goodness-of-fit test
+#'            \item \code{RSS} the residual sums of squares term
+#'            \item \code{X2} the pearson chi-squared statistic
+#'           }
+#'
+#' @note For vectors, this function is a convenient function for the \code{\link{chisq.test}},
+#'         performing goodness-of-fit test.
+#'         \cr \cr
+#'         For \code{glm}-objects, this function performs a goodness-of-fit test
+#'         based on the \code{X2GOFtest} function of the \code{binomTools} package.
+#'         A well-fitting model shows no significant difference between
+#'         the model and the observed data, i.e. the reported p-values should be
+#'         greater than 0.05.
 #'
 #' @examples
 #' data(efc)
@@ -331,18 +352,235 @@ mwu <- function(var, grp, distribution="asymptotic", weights=NULL) {
 #' # equal to population
 #' chisq_gof(efc$e42dep, prop.table(table(efc$e42dep)))
 #'
+#' # goodness-of-fit test for logistic regression
+#' efc$services <- dicho(efc$tot_sc_e, "v", 0, asNum = TRUE)
+#' fit <- glm(services ~ neg_c_7 + c161sex + e42dep,
+#'            data = efc,
+#'            family = binomial(link = "logit"))
+#' chisq_gof(fit)
+#'
 #' @export
-chisq_gof <- function(var, prob, weights=NULL) {
-  # performs a Chi-square goodnes-of-fit-test
-  if (!is.null(weights)) var <- weight(var, weights)
-  dummy <- as.vector(table(var))
-  # goodness of fit-test. x is one-dimensional and
-  # y not given
-  chi2gof <- chisq.test(dummy, p = prob)
-  return (chi2gof)
+chisq_gof <- function(x, prob = NULL, weights = NULL) {
+  if (any(class(x) == "glm")) {
+    # ------------------------------------
+    # This is an adapted version from the
+    # "binomTools" package. The "X2GOFtest()"
+    # function did not work when model data frame
+    # had missing values.
+    # ------------------------------------
+    y_hat <- fitted(x)
+    wt <- x$prior.weight
+    vJ <- wt * y_hat * (1 - y_hat)
+    cJ <- (1 - 2 * y_hat) / vJ
+    X2 <- sum(resid(x, type = "pearson") ^ 2)
+    form <- as.formula(x$formula)
+    form[[2]] <- as.name("cJ")
+    # use model matrix instead of data values,
+    # because data may contain more variables
+    # than needed, and due to missing may have
+    # different row length
+    dat <- na.omit(x$model)
+    dat$cJ <- cJ
+    dat$vJ <- vJ
+    RSS <- sum(resid(lm(form, data = dat, weights = vJ)) ^ 2)
+    A <- 2 * (length(y_hat) - sum(1 / wt))
+    z <- (X2 - x$df.residual) / sqrt(A + RSS)
+    p.value <- 2 * pnorm(abs(z), lower.tail = FALSE)
+    chi2gof <- list(p.value = p.value,
+                    z.score = z,
+                    RSS = RSS,
+                    X2 = X2)
+    class(chi2gof) <- "chi2gof"
+  } else {
+    # check if we have probs
+    if (is.null(prob)) {
+      warning("'prob' needs to be specified.", call. = F)
+      return(invisible(NULL))
+    }
+    # performs a Chi-square goodnes-of-fit-test
+    if (!is.null(weights)) x <- weight(x, weights)
+    dummy <- as.vector(table(x))
+    # goodness of fit-test. x is one-dimensional and
+    # y not given
+    chi2gof <- chisq.test(dummy, p = prob)
+  }
+  return(chi2gof)
 }
 
 
+#' @title Performs a Hosmer-Lemeshow Goodness-of-fit-test
+#' @name hoslem_gof
+#'
+#' @description This method performs a Hosmer-Lemeshow goodness-of-fit-test
+#'                for \code{\link{glm}}s or \code{\link[lme4]{glmer}}s for
+#'                binary data.
+#'
+#' @param x a fitted \code{\link{glm}} or \code{\link[lme4]{glmer}}.
+#' @param g number of bins to divide the data Default is 10.
+#'
+#' @return An object of class \code{hoslem_test} with
+#'           following values:
+#'           \itemize{
+#'            \item \code{chisq} the Hosmer-Lemeshow chi-squared statistic
+#'            \item \code{df} degrees of freedom
+#'            \item \code{p.value}	the p-value for the goodness-of-fit test
+#'           }
+#'
+#' @note A well-fitting model shows no significant difference between
+#'         the model and the observed data, i.e. the reported p-value should be
+#'         greater than 0.05.
+#'
+#' @seealso \code{\link{pseudo_r2}}
+#'
+#' @examples
+#' data(efc)
+#'
+#' # goodness-of-fit test for logistic regression
+#' efc$services <- dicho(efc$tot_sc_e, "v", 0, asNum = TRUE)
+#' fit <- glm(services ~ neg_c_7 + c161sex + e42dep,
+#'            data = efc,
+#'            family = binomial(link = "logit"))
+#' hoslem_gof(fit)
+#'
+#' @export
+hoslem_gof <- function(x, g = 10) {
+  # ---------------------------------------
+  # check for valid object class
+  # ---------------------------------------
+  if (!any(class(x) == "glmerMod") && !any(class(x) == "glm")) {
+    stop("'x' must be an object of class 'glm' or 'glmerMod'.", call. = F)
+  }
+  # ---------------------------------------
+  # mixed models (lme4)
+  # ---------------------------------------
+  if (any(class(x) == "glmerMod")) {
+    # ---------------------------------------
+    # check for package availability
+    # ---------------------------------------
+    if (!requireNamespace("lme4", quietly = TRUE)) {
+      stop("Package 'lme4' needed for this function to work. Please install it.", call. = FALSE)
+    }
+    y <- lme4::getME(x, "y")
+    yhat <- fitted(x)
+  } else {
+    y <- x$y
+    yhat <- fitted(x)
+  }
+  cutyhat <- cut(yhat,
+                 breaks = quantile(yhat, probs = seq(0, 1, 1 / g)),
+                 include.lowest = TRUE)
+  obs <- xtabs(cbind(1 - y, y) ~ cutyhat)
+  expect <- xtabs(cbind(1 - yhat, yhat) ~ cutyhat)
+  chisq <- sum((obs - expect)^2 / expect)
+  p.value <- 1 - pchisq(chisq, g - 2)
+  hoslem <- list(chisq = chisq,
+                 df = g - 2,
+                 p.value = p.value)
+  class(hoslem) <- "hoslem_test"
+  return(hoslem)
+}
+
+
+#' @title Compute Nagelkerke's and Cox-Snell's Pseudo R-squared
+#' @name pseudo_r2
+#'
+#' @description This method calculates Nagelkerke's and Cox-Snell's
+#'                pseudo-r-squared-values of \code{\link{glm}}s for
+#'                binary data.
+#'
+#' @param x a fitted \code{\link{glm}}.
+#'
+#' @return An object of class \code{pseudo_r2} with
+#'           following values:
+#'           \itemize{
+#'            \item \code{CoxSnell} Cox-Snell's pseudo-r-squared-value
+#'            \item \code{Nagelkerke} Nagelkerke's pseudo-r-squared-value
+#'           }
+#'
+#' @seealso \code{\link{cod}}
+#'
+#' @examples
+#' data(efc)
+#'
+#' # Pseudo-R-squared values
+#' efc$services <- dicho(efc$tot_sc_e, "v", 0, asNum = TRUE)
+#' fit <- glm(services ~ neg_c_7 + c161sex + e42dep,
+#'            data = efc,
+#'            family = binomial(link = "logit"))
+#' pseudo_r2(fit)
+#'
+#' @export
+pseudo_r2 <- function(x) {
+  n <- nrow(x$model)
+  CoxSnell <- 1 - exp((x$deviance - x$null) / n)
+  Nagelkerke <- CoxSnell / (1 - exp(-x$null / n))
+  pseudor2 <- list(CoxSnell, Nagelkerke)
+  names(pseudor2) <- c("CoxSnell", "Nagelkerke")
+  return(pseudor2)
+}
+
+
+#' @title Computes Tjur's Coefficient of Discrimination
+#' @name cod
+#'
+#' @description This method calculates the Coefficient of Discrimination \code{D}
+#'                for \code{\link{glm}}s or \code{\link[lme4]{glmer}}s for
+#'                binary data. It is an alternative to other Pseudo-R-squared values
+#'                like Nakelkerke's R2 or Cox-Snell R2.
+#'
+#' @param x a fitted \code{\link{glm}} or \code{\link[lme4]{glmer}}.
+#'
+#' @return The \code{D} Coefficient of Discrimination, also known as
+#'           Tjur's R-squared value.
+#'
+#' @note The Coefficient of Discrimination \code{D} can be read like any
+#'         other (Pseudo-)R-squared value.
+#'
+#' @references Tjur T (2009) Coefficients of determination in logistic regression models -
+#'               a new proposal: The coefficient of discrimination. The American Statistician,
+#'               63(4): 366-372
+#'
+#' @examples
+#' data(efc)
+#'
+#' # Tjur's R-squared value
+#' efc$services <- dicho(efc$tot_sc_e, "v", 0, asNum = TRUE)
+#' fit <- glm(services ~ neg_c_7 + c161sex + e42dep,
+#'            data = efc,
+#'            family = binomial(link = "logit"))
+#' cod(fit)
+#'
+#' @export
+cod <- function(x) {
+  # ---------------------------------------
+  # check for valid object class
+  # ---------------------------------------
+  if (!any(class(x) == "glmerMod") && !any(class(x) == "glm")) {
+    stop("'x' must be an object of class 'glm' or 'glmerMod'.", call. = F)
+  }
+  # ---------------------------------------
+  # mixed models (lme4)
+  # ---------------------------------------
+  if (any(class(x) == "glmerMod")) {
+    # ---------------------------------------
+    # check for package availability
+    # ---------------------------------------
+    if (!requireNamespace("lme4", quietly = TRUE)) {
+      stop("Package 'lme4' needed for this function to work. Please install it.", call. = FALSE)
+    }
+    y <- lme4::getME(x, "y")
+    pred <- predict(x, type = "response", re.form = NULL)
+  } else {
+    y <- x$y
+    pred <- predict.glm(x, type = "response")
+  }
+  categories <- unique(y)
+  m1 <- mean(pred[which(y == categories[1])], na.rm = T)
+  m2 <- mean(pred[which(y == categories[2])], na.rm = T)
+
+  return(abs(m2 - m1))
+}
+
 #' @title Calculates Cronbach's Alpha for a matrix
 #' @name cronb
 #' @description This function calculates the Cronbach's alpha value for each column
@@ -360,13 +598,13 @@ cronb <- function(df) {
   df <- na.omit(df)
   if (is.null(ncol(df)) || ncol(df) < 2) {
     warning("Too less columns in this factor to calculate alpha value!", call. = F)
-    return (NULL)
+    return(NULL)
   }
-  return (dim(df)[2] / (dim(df)[2] - 1) * (1 - sum(apply(df, 2, var)) / var(rowSums(df))))
+  return(dim(df)[2] / (dim(df)[2] - 1) * (1 - sum(apply(df, 2, var)) / var(rowSums(df))))
 }
 
 
-#' @title Performs a reliability test on an item scale.
+#' @title Performs a reliability test on an item scale
 #' @name reliab_test
 #' @description This function calculates the item discriminations (corrected item-total
 #'                correlations for each item of \code{x} with the remaining items) and
@@ -407,6 +645,7 @@ cronb <- function(df) {
 #' colnames(x) <- varlabs[c(start:end)]
 #'
 #' \dontrun{
+#' library(sjPlot)
 #' sjt.df(reliab_test(x),
 #'        describe = FALSE,
 #'        showCommentRow = TRUE,
@@ -420,6 +659,7 @@ cronb <- function(df) {
 #' \dontrun{
 #' factors <- sjt.pca(x)$factor.index
 #' findex <- sort(unique(factors))
+#' library(sjPlot)
 #' for (i in 1:length(findex)) {
 #'  rel.df <- subset(x, select = which(factors == findex[i]))
 #'  if (ncol(rel.df) >= 3) {
@@ -444,7 +684,7 @@ reliab_test <- function(x, scaleItems=FALSE, digits=3) {
   # -----------------------------------
   if (!is.matrix(x) && !is.data.frame(x)) {
     warning("'x' needs to be a data frame or matrix.", call. = F)
-    return (NULL)
+    return(NULL)
   }
   # -----------------------------------
   # remember item (column) names for return value
@@ -508,18 +748,19 @@ reliab_test <- function(x, scaleItems=FALSE, digits=3) {
 }
 
 
-#' @title Computes a mean inter-item-correlation.
+#' @title Compute mean inter-item-correlation
 #' @name mic
 #' @description This function calculates a mean inter-item-correlation, i.e.
 #'                a correlation matrix of \code{data} will be computed (unless
 #'                \code{data} is already a \code{\link{cor}}-object) and the mean
-#'                of all added item's correlation values is returned.
+#'                of the sum of all item's correlation values is returned.
 #'                Requires either a data frame or a computed \code{\link{cor}}-object.
 #'
-#' @param data A correlation object, built with the R-\code{\link{cor}}-function, or a data frame
+#' @param data A correlation object (see \code{\link{cor}}-function), or a data frame
 #'          which correlations should be calculated.
 #' @param corMethod Indicates the correlation computation method. May be one of
 #'          \code{"spearman"} (default), \code{"pearson"} or \code{"kendall"}.
+#'          You may use initial letter only.
 #' @return The value of the computed mean inter-item-correlation.
 #'
 #' @examples
@@ -528,16 +769,22 @@ reliab_test <- function(x, scaleItems=FALSE, digits=3) {
 #' # -------------------------------
 #' data(efc)
 #' # recveive first item of COPE-index scale
-#' start <- which(colnames(efc)=="c82cop1")
+#' start <- which(colnames(efc) == "c82cop1")
 #' # recveive last item of COPE-index scale
-#' end <- which(colnames(efc)=="c90cop9")
+#' end <- which(colnames(efc) == "c90cop9")
 #' # create data frame with COPE-index scale
-#' df <- as.data.frame(efc[,c(start:end)])
+#' df <- data.frame(efc[, c(start:end)])
 #'
 #' mic(df)
 #'
 #' @export
 mic <- function(data, corMethod="pearson") {
+  # -----------------------------------
+  # Check parameter
+  # -----------------------------------
+  if (corMethod == "s") corMethod <- "spearman"
+  if (corMethod == "p") corMethod <- "pearson"
+  if (corMethod == "k") corMethod <- "kendall"
   # -----------------------------------
   # Mean-interitem-corelation
   # -----------------------------------
@@ -554,7 +801,7 @@ mic <- function(data, corMethod="pearson") {
   for (j in 1:(ncol(corr) - 1)) {
     # first correlation is always "1" (self-correlation)
     for (i in (j + 1):nrow(corr)) {
-      # check four valid bound
+      # check for valid bound
       if (i <= nrow(corr) && j <= ncol(corr)) {
         # add up all subsequent values
         meanic <- c(meanic, corr[i, j])
@@ -563,7 +810,7 @@ mic <- function(data, corMethod="pearson") {
       }
     }
   }
-  return (mean(meanic))
+  return(mean(meanic))
 }
 
 
@@ -602,11 +849,11 @@ table_values <- function(tab, digits=2) {
   # -------------------------------------
   # return results
   # -------------------------------------
-  invisible (structure(class = "sjutablevalues",
-                       list(cell = tab.cell,
-                            row = tab.row,
-                            col = tab.col,
-                            expected = tab.expected)))
+  invisible(structure(class = "sjutablevalues",
+                      list(cell = tab.cell,
+                           row = tab.row,
+                           col = tab.col,
+                           expected = tab.expected)))
 }
 
 
@@ -631,7 +878,7 @@ phi <- function(tab) {
   if (all(class(tab) != "ftable")) tab <- ftable(tab)
   tb <- summary(MASS::loglm(~1 + 2, tab))$tests
   phi_val <- sqrt(tb[2, 1] / sum(tab))
-  return (phi_val)
+  return(phi_val)
 }
 
 
@@ -654,22 +901,50 @@ cramer <- function(tab) {
   if (all(class(tab) != "ftable")) tab <- ftable(tab)
   phi_val <- phi(tab)
   cramer <- sqrt(phi_val^2 / min(dim(tab) - 1))
-  return (cramer)
+  return(cramer)
 }
 
 
 #' @title Compute standard error for variables
 #' @name std_e
-#' @description Compute standard error for variables
+#' @description Compute standard error for variable or for all variables
+#'                of a data frame.
 #'
-#' @param x a (numeric) vector / variable.
-#' @return The standard error of variable \code{x}.
+#' @param x a (numeric) vector / variable or a data frame.
+#' @return The standard error of variable \code{x}, or for each variable
+#'           if \code{x} is a data frame.
 #'
 #' @examples
 #' std_e(rnorm(n = 100, mean = 3))
 #'
+#' data(efc)
+#' std_e(efc[, 1:3])
+#'
 #' @export
-std_e <- function(x) sqrt(var(x, na.rm = TRUE) / length(na.omit(x)))
+std_e <- function(x) {
+  if (is.matrix(x) || is.data.frame(x)) {
+    # init return variables
+    stde <- c()
+    stde_names <- c()
+    # iterate all columns
+    for (i in 1:ncol(x)) {
+      # get and save standard error for each variable
+      # of the data frame
+      stde <- c(stde, std_e_helper(x[[i]]))
+      # save column name as variable name
+      stde_names <- c(stde_names, colnames(x)[i])
+    }
+    # set names to return vector
+    names(stde) <- stde_names
+    # return results
+    return(stde)
+  } else {
+    return(std_e_helper(x))
+  }
+}
+
+std_e_helper <- function(x) sqrt(var(x, na.rm = TRUE) / length(na.omit(x)))
+
 
 
 #' @title Compute coefficient of variation
@@ -684,28 +959,52 @@ std_e <- function(x) sqrt(var(x, na.rm = TRUE) / length(na.omit(x)))
 #'          \code{\link[nlme]{lme}} (nlme).
 #' @return The coefficient of variation of \code{x}.
 #'
-#' @seealso \itemize{
-#'            \item \href{http://www.ats.ucla.edu/stat/mult_pkg/faq/general/coefficient_of_variation.htm}{UCLA-FAQ: What is the coefficient of variation?}
-#'            \item \code{\link{rmse}}
-#'          }
+#' @details The advantage of the cv is that it is unitless. This allows
+#'            coefficient of variation to be compared to each other in ways
+#'            that other measures, like standard deviations or root mean
+#'            squared residuals, cannot be
+#'            (\href{http://www.ats.ucla.edu/stat/mult_pkg/faq/general/coefficient_of_variation.htm}{source: UCLA-FAQ}).
+#'
+#' @seealso \code{\link{rmse}}
+#'
+#' @references \href{http://www.ats.ucla.edu/stat/mult_pkg/faq/general/coefficient_of_variation.htm}{UCLA-FAQ: What is the coefficient of variation?}
 #'
 #' @examples
 #' data(efc)
 #' cv(efc$e17age)
 #'
+#' fit <- lm(neg_c_7 ~ e42dep, data = efc)
+#' cv(fit)
+#'
+#' library(lme4)
+#' fit <- lmer(Reaction ~ Days + (Days | Subject), sleepstudy)
+#' cv(fit)
+#'
+#' library(nlme)
+#' fit <- lme(distance ~ age, data = Orthodont) # random is ~ age
+#' cv(fit)
+#'
 #' @export
 cv <- function(x) {
   # check if we have a fitted linear model
-  if (class(x) == "lm" || class(x) == "lmerMod" || class(x) == "lme") {
+  if (class(x) == "lm" || any(class(x) == "lmerMod") || any(class(x) == "lme") || any(class(x) == "merModLmerTest")) {
     if (class(x) == "lm") {
       # dependent variable in lm
       dv <- x$model[[1]]
-    } else if (class(x) == "lmerMod") {
+    } else if (any(class(x) == "lmerMod") || any(class(x) == "merModLmerTest")) {
+      # check for package availability
+      if (!requireNamespace("lme4", quietly = TRUE)) {
+        stop("Package 'lme4' needed for this function to work. Please install it.", call. = FALSE)
+      }
       # dependent variable in lmerMod
-      dv <- x@frame[[1]]
-    } else if (class(x) == "lme") {
+      dv <- lme4::getME(fit, "y")
+    } else if (any(class(x) == "lme")) {
+      # check for package availability
+      if (!requireNamespace("nlme", quietly = TRUE)) {
+        stop("Package 'nlme' needed for this function to work. Please install it.", call. = FALSE)
+      }
       # dependent variable in lme
-      dv <- x$data[[1]]
+      dv <- unname(nlme::getResponse(fit))
     }
     # compute mean of dependent variable
     mw <- mean(dv, na.rm = TRUE)
@@ -736,17 +1035,75 @@ cv <- function(x) {
 #'
 #' @param fit a fitted linear model of class \code{\link{lm}},
 #'          \code{\link[lme4]{merMod}} (lme4) or \code{\link[nlme]{lme}} (nlme).
-#' @return The root mean squared error of \code{fit}.
+#' @param normalized logical, use \code{TRUE} if normalized rmse should be returned.
+#'
+#' @return The root mean squared error of \code{fit}; or the normalized
+#'           root mean squared error of \code{fit} if \code{normalized = TRUE}.
 #'
 #' @seealso \code{\link{cv}}
 #'
+#' @references \itemize{
+#'              \item \href{http://en.wikipedia.org/wiki/Root-mean-square_deviation}{Wikipedia: RMSD}
+#'              \item \href{http://www.theanalysisfactor.com/assessing-the-fit-of-regression-models/}{Grace-Martin K: Assessing the Fit of Regression Models}
+#'             }
+#'
+#' @note The RMSE is the square root of the variance of the residuals and indicates
+#'         the absolute fit of the model to the data (difference between observed data
+#'         to model's predicted values). "RMSE can be interpreted as the standard
+#'         deviation of the unexplained variance, and has the useful property
+#'         of being in the same units as the response variable. Lower values
+#'         of RMSE indicate better fit. RMSE is a good measure of how accurately
+#'         the model predicts the response, and is the most important criterion
+#'         for fit if the main purpose of the model is prediction."
+#'         (Grace-Martin K: Assessing the Fit of Regression Models).
+#'         \cr \cr
+#'         The normalized RMSE is the proportion of the RMSE related to the
+#'         range of the response variable. Hence, lower values indicate
+#'         less residual variance.
+#'
 #' @examples
 #' data(efc)
-#' fit <- lm(barthtot ~ c160age + c12hour, data=efc)
+#' fit <- lm(barthtot ~ c160age + c12hour, data = efc)
 #' rmse(fit)
 #'
+#' library(lme4)
+#' fit <- lmer(Reaction ~ Days + (Days | Subject), sleepstudy)
+#' rmse(fit)
+#'
+#' # normalized RMSE
+#' library(nlme)
+#' fit <- lme(distance ~ age, data = Orthodont) # random is ~ age
+#' rmse(fit, normalized = TRUE)
+#'
 #' @export
-rmse <- function(fit) sqrt(mean(residuals(fit)^2, na.rm = TRUE))
+rmse <- function(fit, normalized = FALSE) {
+  # ------------------------------------------
+  # compute rmse
+  # ------------------------------------------
+  rmse_val <- sqrt(mean(residuals(fit)^2, na.rm = TRUE))
+  # ------------------------------------------
+  # if normalized, divide by range of response
+  # ------------------------------------------
+  if (normalized) {
+    if (any(class(fit) == "lmerMod") || any(class(fit) == "merModLmerTest")) {
+      # check for package availability
+      if (!requireNamespace("lme4", quietly = TRUE)) {
+        stop("Package 'lme4' needed for this function to work. Please install it.", call. = FALSE)
+      }
+      resp <- lme4::getME(fit, "y")
+    } else if (any(class(fit) == "lme")) {
+      # check for package availability
+      if (!requireNamespace("nlme", quietly = TRUE)) {
+        stop("Package 'nlme' needed for this function to work. Please install it.", call. = FALSE)
+      }
+      resp <- unname(nlme::getResponse(fit))
+    } else {
+      resp <- fit$model[[1]]
+    }
+    rmse_val <- rmse_val / (max(resp, na.rm = T) - min(resp, na.rm = T))
+  }
+  rmse_val
+}
 
 
 #' @title Plot Levene-Test for One-Way-Anova
@@ -823,7 +1180,7 @@ is_crossed <- function(f1, f2) {
   tab <- table(f1, f2)
   # for crossed factors, we should have no zeros in any rows
   # (i.e. each level of f1 also contains any level of f2)
-  return (!any(apply(tab, 1, function(x) any(x==0)) == TRUE))
+  return(!any(apply(tab, 1, function(x) any(x == 0)) == TRUE))
 }
 
 
@@ -871,13 +1228,129 @@ is_nested <- function(f1, f2) {
   # (or column) that is not zero. If we found more, factors are not nested
   # or rows and columns have to be swapped.
   # check if f1 is nested within f2
-  nested <- !any(apply(tab, 1, function(x) sum(x!=0) > 1))
+  nested <- !any(apply(tab, 1, function(x) sum(x != 0) > 1))
   if (nested) message("'f1' is nested within 'f2'")
   # swap rows and columns to check whether factors are nested
   # check whether f2 is nested within f1
   if (!nested) {
-    nested <- !any(apply(tab, 2, function(x) sum(x!=0) > 1))
+    nested <- !any(apply(tab, 2, function(x) sum(x != 0) > 1))
     if (nested) message("'f2' is nested within 'f1'")
   }
-  return (nested)
+  return(nested)
 }
+
+
+#' @title Compute Intra-Class-Correlation
+#' @name icc
+#' @description This function calculates the intraclass-correlation
+#'                (icc) for random intercepts of mixed effects models.
+#'                Currently, only \code{\link[lme4]{merMod}} objects
+#'                are supported.
+#'
+#' @param x a fitted mixed effects model (\code{\link[lme4]{merMod}}-class).
+#'
+#' @return A numeric vector with all random intercept intraclass-correlation-coefficients.
+#'
+#' @references \itemize{
+#'               \item Wu S, Crespi CM, Wong WK (2012) Comparison of methods for estimating the intraclass correlation coefficient for binary responses in cancer prevention cluster randomized trials. Contempory Clinical Trials 33: 869-880 (\href{http://dx.doi.org/10.1016/j.cct.2012.05.004}{doi:10.1016/j.cct.2012.05.004})
+#'               \item \href{http://stats.stackexchange.com/questions/18088/intraclass-correlation-icc-for-an-interaction/28100#28100}{CrossValidated (2012) \emph{Intraclass correlation (ICC) for an interaction?}}
+#'               \item \href{http://stats.stackexchange.com/questions/113577/interpreting-the-random-effect-in-a-mixed-effect-model/113825#113825}{CrossValidated (2014) \emph{Interpreting the random effect in a mixed-effect model}}
+#'               \item \href{http://stats.stackexchange.com/questions/67247/how-to-partition-the-variance-explained-at-group-level-and-individual-level/67356#67356}{CrossValidated (2014) \emph{how to partition the variance explained at group level and individual level}}
+#'             }
+#'
+#' @note \emph{Why ICC is useful}
+#'       \enumerate{
+#'        \item It can help you determine whether or not a linear mixed model is even necessary. If you find that the correlation is zero, that means the observations within clusters are no more similar than observations from different clusters.  Go ahead and use a simpler analysis technique.
+#'        \item It can be theoretically meaningful to understand how much of the overall variation in the response is explained simply by clustering.  For example, in a repeated measures psychological study you can tell to what extent mood is a trait (varies among people, but not within a person on different occasions) or state (varies little on average among people, but varies a lot across occasions).
+#'        \item It can also be meaningful to see how the ICC (as well as the between and within cluster variances) changes as variable are added to the model.
+#'       }
+#'       (Grace-Martin K: \emph{The Intraclass Correlation Coefficient in Mixed Models}, \href{http://www.theanalysisfactor.com/the-intraclass-correlation-coefficient-in-mixed-models/}{web})
+#'       \cr \cr
+#'       The calculation of the ICC for generalized linear mixed models is based on
+#'       Wu et al. (2012).
+#'
+#' @examples
+#' \dontrun{
+#' library(lme4)
+#' fit <- lmer(Reaction ~ Days + (Days | Subject), sleepstudy)
+#' icc(fit)
+#'
+#' sleepstudy$mygrp <- sample(1:45, size = 180, replace = T)
+#' fit <- lmer(Reaction ~ Days + (1|mygrp) + (Days | Subject), sleepstudy)
+#' icc(fit)}
+#'
+#' @export
+icc <- function(x) {
+  return(icc.lme4(x))
+}
+
+
+icc.lme4 <- function(fit) {
+  # ------------------------
+  # check if suggested package is available
+  # ------------------------
+  if (!requireNamespace("lme4", quietly = TRUE)) {
+    stop("Package 'lme4' needed for this function to work. Please install it.", call. = FALSE)
+  }
+  # ------------------------
+  # check object class
+  # ------------------------
+  if (any(class(fit) == "glmerMod") || any(class(fit) == "lmerMod") || any(class(fit) == "merModLmerTest")) {
+    # ------------------------
+    # random effects variances
+    # ------------------------
+    reva <- summary(fit)$varcor
+    # retrieve only intercepts
+    vars <- lapply(reva, function(x) x[[1]])
+    # residual variances
+    if (any(class(fit) == "glmerMod")) {
+      # for logistic models, we use pi / 3
+      resid_var <- (pi^2) / 3
+    } else {
+      # for linear models, we have a clear
+      # residual variance
+      resid_var <- attr(reva, "sc")^2
+    }
+    # total variance
+    total_var <- sum(sapply(vars, sum), resid_var)
+    # random intercept icc
+    ri.icc <- sapply(vars, function(x) x[1]) / total_var
+    # name values
+    names(ri.icc) <- names(reva)
+    # icc standard errors
+    # ri.icc.se <- unlist(lapply(reva, function(x) attr(x, "stddev")[1]))
+    # names(ri.icc.se) <- paste0(names(reva), " (S.E.)")
+    # return(list(icc = ri.icc, se = ri.icc.se))
+    return(ri.icc)
+  } else {
+    warning("Function 'icc' currently only supports 'merMod' objects (package 'lme4').", call. = F)
+  }
+}
+
+# retrieve variance of random intercepts
+# and residuals
+lmer_var <- function(fit) {
+  reva <- summary(fit)$varcor
+  # retrieve only intercepts
+  vars <- unlist(lapply(reva, function(x) x[[1]]))
+  names(vars) <- names(reva)
+  # residual variances
+  if (any(class(fit) == "glmerMod")) {
+    # for logistic models, we use pi / 3
+    resid_var <- (pi^2) / 3
+  } else {
+    # for linear models, we have a clear
+    # residual variance
+    resid_var <- attr(reva, "sc")^2
+  }
+  return(list('Between group variance' = vars,
+              'Within group variance' = resid_var))
+}
+
+
+lm_pval_fstat <- function(x) {
+  if (class(x) != "lm") stop("Not an object of class 'lm'.", call. = F)
+  f <- summary(x)$fstatistic
+  p <- pf(f[1], f[2], f[3], lower.tail = F)
+  return(as.vector(p))
+}
\ No newline at end of file
